==> corosync_2.4.2.orig.tar.gz: corosync-2.4.2/qdevices/qdevice-net-poll-array-user-data.h <==
/*
 * Copyright (c) 2015-2016 Red Hat, Inc.
 *
 * All rights reserved.
 *
 * Author: Jan Friesse (jfriesse@redhat.com)
 *
 * This software licensed under BSD license, the text of which follows:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * - Neither the name of the Red Hat, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _QDEVICE_NET_POLL_ARRAY_USER_DATA_H_
#define _QDEVICE_NET_POLL_ARRAY_USER_DATA_H_

#include "unix-socket-client.h"

#ifdef __cplusplus
extern "C" {
#endif

enum qdevice_net_poll_array_user_data_type {
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_VOTEQUORUM,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_CMAP,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_IPC_SOCKET,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_SOCKET,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_IPC_CLIENT,
};

struct qdevice_net_poll_array_user_data {
	enum qdevice_net_poll_array_user_data_type type;
	struct unix_socket_client *ipc_client;
};

#ifdef __cplusplus
}
#endif

#endif /* _QDEVICE_NET_POLL_ARRAY_USER_DATA_H_ */

==> corosync_2.4.3.orig.tar.gz: corosync-2.4.3/qdevices/qdevice-net-poll-array-user-data.h <==
/*
 * Copyright (c) 2015-2017 Red Hat, Inc.
 *
 * All rights reserved.
 *
 * Author: Jan Friesse (jfriesse@redhat.com)
 *
 * This software licensed under BSD license, the text of which follows:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * - Neither the name of the Red Hat, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _QDEVICE_NET_POLL_ARRAY_USER_DATA_H_
#define _QDEVICE_NET_POLL_ARRAY_USER_DATA_H_

#include "unix-socket-client.h"

#ifdef __cplusplus
extern "C" {
#endif

enum qdevice_net_poll_array_user_data_type {
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_VOTEQUORUM,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_CMAP,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_IPC_SOCKET,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_SOCKET,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_IPC_CLIENT,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_HEURISTICS_CMD_SEND,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_HEURISTICS_CMD_RECV,
	QDEVICE_NET_POLL_ARRAY_USER_DATA_TYPE_HEURISTICS_LOG_RECV,
};

struct qdevice_net_poll_array_user_data {
	enum qdevice_net_poll_array_user_data_type type;
	struct unix_socket_client *ipc_client;
};

#ifdef __cplusplus
}
#endif

#endif /* _QDEVICE_NET_POLL_ARRAY_USER_DATA_H_ */
